---
title: Section 508 and WCAG 2.0 Compliance
page_title: Section 508 and WCAG 2.0 Compliance | Kendo UI Accessibility Support
description: "Learn more about the Section 508 and WCAG 2.0 Accesibility support provided by Kendo UI controls."
slug: section508_wcag20_accessibility_support
position: 3
---

# Section 508 and WCAG 2.0 Compliance

The Kendo UI widgets follow the [W3C Web Content Accessibility Guidelines 2.0](https://www.w3.org/TR/WCAG/).

They set the standards for applications for providing accessible content. Depending on the number of guidelines that is followed when building an application, W3C defines three levels of accessibility conformance&mdash;A, AA, and AAA levels.

The Kendo UI components also conform to the technical standards set out in Section 508 of the Rehabilitation Act. They represent the law that requires all Federal Agencies to make their electronic and information technology accessible to people with disabilities. For detailed information on the accessibility features according to the Section 508 Web content standards Kendo UI delivers, refer to the article about [Section 508]({% slug section508_accessibility_support %}).

Applications built with components that adhere to these guidelines will not only be accessible to people with disabilities, but also to users of all kinds of devices and interfaces such as desktop browser, voice browser, mobile phone, automobile-based personal computer, and so on.

The following table shows the Section 508 and WCAG 2.0 Compliance level of support for the Kendo UI widgets. The report is based on results from tests performed on our **Basic Usage** demos.

**Table 1: 508 and WCAG 2.0 compliance with Kendo UI widgets**

|Component |508|WCAG 2.0|Demo
|:---          |:---|:---  |:---
|AutoComplete  |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/autocomplete/index)
|BarCode	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/barcode/index)
|Button 	   |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/button/index)
|ButtonGroup   |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/buttongroup/index)
|Calendar	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/calendar/index)
|Charts        |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/chart-api/index)
|ComboBox      |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/combobox/index)
|ColorPicker   |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/colorpicker/index)
|DateInput	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/dateinput/index)
|DatePicker	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/datepicker/index)
|DateTimePicker|Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/datetimepicker/index)
|Diagram	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/diagram/index)
|Dialog	       |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/dialog/index)
|DropDownList  |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/dropdownlist/index)
|Editor        |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/editor/index)
|Gantt         |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/gantt/index)
|Grid          |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/grid/index)
|LinearGauge   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/linear-gauge/index)
|ListBox       |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/listbox/index)
|ListView	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/listview/index)
|Map	       |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/map/index)
|MaskedTextbox |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/maskedtextbox/index)
|Menu          |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/menu/index)
|MediaPlayer   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/mediaplayer/index)
|MultiSelect   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/multiselect/index)
|Notification  |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/notification/index)
|NumericTextbox|Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/numerictextbox/index)
|PanelBar	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/panelbar/index)
|PivotGrid	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/pivotgrid/index)
|QRCode	   	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/qrcode/index)
|RadialGauge   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/radial-gauge/index)
|RadioButton   |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/styling/radios)
|Responsive Panel |Yes |AA |[Browse](http://demos.telerik.com/kendo-ui/responsive-panel/index)
|ScrollView	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/scrollview/index)
|Scheduler	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/scheduler/index)
|Slider	       |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/slider/index)
|Sortable	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/sortable/index)
|Splitter      |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/splitter/index)
|Spreadsheet   |No  |-   |
|Switch        |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/switch/index)
|TabStrip	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/tabstrip/index)
|TimePicker	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/timepicker/index)
|ToolBar	   |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/toolbar/index)
|Tooltip	   |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/tooltip/index)
|TreeList	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/treelist/index)
|TreeView	   |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/treeview/index)
|Upload 	   |Yes |AA  |[Browse](http://demos.telerik.com/kendo-ui/upload/index)
|Window 	   |Yes |AAA |[Browse](http://demos.telerik.com/kendo-ui/window/index)

## Special Considerations

Several Kendo UI widgets feature complex rendering which affects their accessibility standards support provisioned by Section 508.

### Label Element Support

Widgets, such as the ComboBox, MultiSelect, and NumericTextBox, hide their initial `input` or `select` element which breaks the [`label.for`](https://developer.mozilla.org/en/docs/Web/HTML/Element/label#attr-for) focus on click functionality. In general, the browser cannot focus hidden elements. This results in the inability of the `label` element to focus the corresponding widget.

**Solution**

Place the widget inside the `label` element which in turn focuses the first visible element. Avoid using the `for` attribute because when it is applied to the `label` element, the respective widget does not focus. Instead, use the 'aria-labelledby' attribute on the input to point to its wrapping `label` element:

###### Example

```
  <label id="label">
    Amount:
    <input id="numerictextbox" aria-labelledby="label"/>
  </label>
  <script>
    $(function() {
      $("#numerictextbox").kendoNumericTextBox();
    });
  </script>
```

## See Also

* [Overview of Accessibility Features in Kendo UI]({% slug overview_accessibility_support_kendoui %})
* [Section 508 Support in Kendo UI]({% slug section508_accessibility_support %})
* [WAI-ARIA Support in Kendo UI]({% slug wai_aria_accessibility_support %})
* [Keyboard Support in Kendo UI]({% slug keyboard_shortcuts_accessibility_support %})
* [Right-to-Left Language Support in Kendo UI]({% slug right_toleft_languages_accessibility_support %})
* [Working with the Kendo UI High-Contrast Theme]({% slug high_contrast_theme_accessibility_support %})
* [Five Tips for Accessible Charts with Kendo UI]({% slug charts_accessibility_support %})
